- Fix bug `#29`_: Issues with `xoutil.symbols.symbol`:class: documentation and
  implementation.

.. _#29: https://gitlab.lahavane.com/merchise/xoutil/issues/29

- Fix bug `#30`_: It was possible to define a dimension with two (or more)
  incompatible canonical units.

.. _#30: https://gitlab.lahavane.com/merchise/xoutil/issues/30

- Fix bug `#33`_: Reusing a context leaves the context unusable.

.. _#33: https://gitlab.lahavane.com/merchise/xoutil/issues/33

- Renamed ``xoutil.tasking.StandardWait`` to
  `xoutil.tasking.ConstantWait`:class:.  This introduced bug `#31`_, which is
  now fixed.

.. _#31: https://gitlab.lahavane.com/merchise/xoutil/issues/31
